.. DF_Cereal documentation master file, created by
   sphinx-quickstart on Wed Apr 19 14:07:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

DF_ereal Dataframe Serialization plyaground
===========================================


**Install Buckaroo**::

   pip install df_cereal




.. toctree::
   :maxdepth: 2
   :caption: Sitemap:

   install
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

* `Buckaroo on github <https://github.com/paddymul/df_cereal>`_
